==> opigno_lms-7.x-1.19-core.tar.gz: opigno_lms-7.x-1.19/profiles/opigno_lms/modules/contrib/h5p/modules/h5peditor/h5peditor/language/nn.js <==
H5PEditor.language.core = {
  missingTranslation: '[Manglar oversettelse :key]',
  loading: 'Lastar :type, ver venleg og vent...',
  selectLibrary: 'Vel biblioteket du ønskjer å bruke for innhaldet ditt.',
  unknownFieldPath: 'Kan ikkje finne ":path".',
  notImageField: '":path" er ikkje eit bilete.',
  notImageOrDimensionsField: '":path" er korkje eit bilete- eller dimensjonsfelt.',
  requiredProperty: '":property" er påkravd og må ha ein verdi.',
  onlyNumbers: '":property" kan berre innhalde tal.',
  exceedsMax: '":property" overstig maksverdien på :max.',
  exceedsMin: '":property" er mindre enn minimumsverdien på :min.',
  outOfStep: '":property" kan berre endrast i steg på :step.',
  addFile: 'Legg til fil',
  removeFile: 'Fjern fil',
  confirmRemoval: 'Er du sikker på at du ønskjer å fjerne denne :type?',
  changeFile: 'Bytt fil',
  semanticsError: 'Semantikkfeil: :error',
  missingProperty: 'Feltet :index manglar :property attributten sin.',
  expandCollapse: 'Utvid/Slå saman',
  addEntity: 'Legg til :entity',
  tooLong: 'Feltets verdi er for lang, den må vere på :max tegn eller mindre.',
  invalidFormat: 'Feltets verdi er på eit ugyldig format eller bruker ulovlege tegn.',
  confirmChangeLibrary: 'Er du sikker på at du ønskjer å byte bibliotek?',
  moreLibraries: 'Sjå etter <a href="http://h5p.org/content-types-and-applications" target="_blank">fleir innhaldstypar</a> på h5p.org',
  commonFields: 'Innstillinger og tekstar',
  commonFieldsDescription: 'Her kan du redigere innstillinger eller oversette tekstar som brukast i dette innhaldet.',
  uploading: 'Lastar opp fil, ver venleg og vent...',
  noFollow: 'Kunne ikkje følge feltet ":path".',
  editCopyright: 'Rediger opphavsrett',
  close: 'Lukk',
  tutorialAvailable: 'Veiledning tilgjengelig',
  editMode: 'Redigeringsmodus',
  listLabel: 'Liste'
};

==> opigno_lms-7.x-1.20-core.tar.gz: opigno_lms-7.x-1.20/profiles/opigno_lms/modules/contrib/h5p/modules/h5peditor/h5peditor/language/nn.js <==
H5PEditor.language.core = {
  missingTranslation: '[Manglar oversettelse :key]',
  loading: 'Lastar :type, ver venleg og vent...',
  selectLibrary: 'Vel biblioteket du ønskjer å bruke for innhaldet ditt.',
  unknownFieldPath: 'Kan ikkje finne ":path".',
  notImageField: '":path" er ikkje eit bilete.',
  notImageOrDimensionsField: '":path" er korkje eit bilete- eller dimensjonsfelt.',
  requiredProperty: '":property" er påkravd og må ha ein verdi.',
  onlyNumbers: '":property" kan berre innhalde tal.',
  exceedsMax: '":property" overstig maksverdien på :max.',
  exceedsMin: '":property" er mindre enn minimumsverdien på :min.',
  outOfStep: '":property" kan berre endrast i steg på :step.',
  addFile: 'Legg til fil',
  removeFile: 'Fjern fil',
  confirmRemoval: 'Er du sikker på at du ønskjer å fjerne denne :type?',
  changeFile: 'Bytt fil',
  semanticsError: 'Semantikkfeil: :error',
  missingProperty: 'Feltet :index manglar :property attributten sin.',
  expandCollapse: 'Utvid/Slå saman',
  addEntity: 'Legg til :entity',
  tooLong: 'Feltets verdi er for lang, den må vere på :max tegn eller mindre.',
  invalidFormat: 'Feltets verdi er på eit ugyldig format eller bruker ulovlege tegn.',
  confirmChangeLibrary: 'Gjør du dette mister du alt arbeid gjort med nåværande innhaldstype. Er du sikker på at du ønskjer å byte innhaldstype?',
  moreLibraries: 'Sjå etter <a href="http://h5p.org/content-types-and-applications" target="_blank">fleir innhaldstypar</a> på h5p.org',
  commonFields: 'Innstillinger og tekstar',
  commonFieldsDescription: 'Her kan du redigere innstillinger eller oversette tekstar som brukast i dette innhaldet.',
  uploading: 'Lastar opp fil, ver venleg og vent...',
  noFollow: 'Kunne ikkje følge feltet ":path".',
  editCopyright: 'Rediger opphavsrett',
  close: 'Lukk',
  tutorialAvailable: 'Veiledning tilgjengelig',
  editMode: 'Redigeringsmodus',
  listLabel: 'Liste',
  uploadError: 'Filopplasting feilet',
  fileToLarge: 'Filen du prøver å laste opp kan være for stor.',
  noSemantics: 'Feil, kunne ikke laste skjemaet for innholdstypen.'
};
